@@ -7,19 +7,23 @@ use Carp;
 use DDP ( show_unicode => 1 );
 use Exporter qw(import);
 use JSON::Path 'jpath1';
+use JSON::XS;
 use Params::ValidationCompiler qw(validation_for);
 use Test::BDD::Cucumber::Definitions qw(S);
 use Test::BDD::Cucumber::Definitions::Struct::Types qw(:all);
 use Test::More;
+use Try::Tiny;
 
-our $VERSION = '0.18';
+our $VERSION = '0.19';
 
 our @EXPORT_OK = qw(
+    read_content
     jsonpath_eq jsonpath_re
 );
 our %EXPORT_TAGS = (
     util => [
         qw(
+            read_content
             jsonpath_eq jsonpath_re
             )
     ]
@@ -30,6 +34,37 @@ $JSON::Path::Safe = 0;    ## no critic (Variables::ProhibitPackageVars)
 
 ## no critic [Subroutines::RequireArgUnpacking]
 
+sub read_content {
+
+    # Clean data
+    S->{struct}->{data} = undef;
+
+    my $error;
+
+    my $decoded_content = S->{http}->{response_object}->decoded_content();
+
+    S->{struct}->{data} = try {
+        decode_json($decoded_content);
+    }
+    catch {
+        $error = "Could not read http response content as JSON: $_[0]";
+
+        return;
+    };
+
+    if ($error) {
+        fail(qq{Http response content was read as JSON});
+        diag($error);
+    }
+    else {
+        pass(qq{Http response content was read as JSON});
+    }
+
+    diag( 'Http response content = ' . np $decoded_content );
+
+    return;
+}
+
 my $validator_jsonpath_eq = validation_for(
     params => [
 
