@@ -6,11 +6,16 @@ use warnings;
 use Test::BDD::Cucumber::Definitions qw(Given When Then);
 use Test::BDD::Cucumber::Definitions::Struct qw(:util);
 
-our $VERSION = '0.18';
+our $VERSION = '0.19';
 
 ## no critic [RegularExpressions::ProhibitCaptureWithoutTest]
 ## no critic [RegularExpressions::RequireExtendedFormatting]
 
+# http response content read JSON
+When qr/http response content read JSON/, sub {
+    read_content();
+};
+
 # struct data element "" eq ""
 Then qr/struct data element "(.+?)" eq "(.*)"/, sub {
     my ( $jsonpath, $value ) = ( $1, $2 );
